@@ -18,7 +18,7 @@ compare_metrics_loc <- function(gene_sigs_list,names_sigs, mRNA_expr_matrix, nam
   if(!dir.exists(file.path(out_dir,'metrics_tables'))){
       dir.create(file.path(out_dir,'metrics_tables'))
   }
-  
+  score_cor_mats <- list()
   for(k in 1:length(names_sigs)){ 
     #for each signature we will make a separate file comparing the datasets
     gene_sig <- gene_sigs_list[[names_sigs[k]]] # load the gene signature
@@ -139,34 +139,18 @@ compare_metrics_loc <- function(gene_sigs_list,names_sigs, mRNA_expr_matrix, nam
         rho_pca1_med <- 0
 
       }
-      #here we put the cor plot of the mean median and pca1 (if we wanted an autocorrelation heatmap of these metrics)
 
-      # autocors_mat <- matrix(0,nrow=3,ncol=3)
-      # row.names(autocors_mat) <- c('Mean' , 'Median','PCA1')
-      # colnames(autocors_mat) <- c('Mean' , 'Median','PCA1')
-      # autocors_mat[1,1] <- 1
-      # autocors_mat[1,2] <- rho_mean_med
-      # autocors_mat[1,3] <- rho_mean_pca1
+      # #here we output the table of mean, median and pca1 scores for each sample to a table
+      # if(length(pca1_scores) > 1){#(!is.null(pca1_scores)){
+      #   output_mat <- cbind(mean_scores[common_score_cols],cbind(med_scores[common_score_cols],pca1_scores[common_score_cols]))
+      #   colnames(output_mat) <- c('Mean_Scores','Median_Scores','PCA1_Scores')
+      # }else{
+      #   output_mat <- cbind(mean_scores[common_score_cols],med_scores[common_score_cols])
+      #   colnames(output_mat) <- c('Mean_Scores','Median_Scores')
 
-      # autocors_mat[2,1] <- rho_mean_med
-      # autocors_mat[2,2] <- 1
-      # autocors_mat[2,3] <- rho_pca1_med
+      # }
 
-      # autocors_mat[3,1] <- rho_mean_pca1
-      # autocors_mat[3,2] <- rho_pca1_med
-      # autocors_mat[3,3] <- 1
-
-      #here we output the table of mean, median and pca1 scores for each sample to a table
-      if(length(pca1_scores) > 1){#(!is.null(pca1_scores)){
-        output_mat <- cbind(mean_scores[common_score_cols],cbind(med_scores[common_score_cols],pca1_scores[common_score_cols]))
-        colnames(output_mat) <- c('Mean_Scores','Median_Scores','PCA1_Scores')
-      }else{
-        output_mat <- cbind(mean_scores[common_score_cols],med_scores[common_score_cols])
-        colnames(output_mat) <- c('Mean_Scores','Median_Scores')
-
-      }
-
-      utils::write.table(output_mat,file=file.path(out_dir,'metrics_tables', paste0('metrics_table_',names_sigs[k],'_',names_datasets[i],'.txt')),quote=F,sep='\t')
+      # utils::write.table(output_mat,file=file.path(out_dir,'metrics_tables', paste0('metrics_table_',names_sigs[k],'_',names_datasets[i],'.txt')),quote=F,sep='\t')
 
       #stores values that will be used in the radarplot
       radar_plot_values[[names_sigs[k]]][[names_datasets[i]]]['rho_mean_med'] <- rho_mean_med
@@ -202,7 +186,206 @@ compare_metrics_loc <- function(gene_sigs_list,names_sigs, mRNA_expr_matrix, nam
   }
   
   cat('Metrics compared successfully.\n', file=file) #output to log
-  
+  #-------------we will also compute the ES scores by 3 different methods here----------------------------
+
+  for(k in 1:length(names_sigs)){ 
+    #for each signature we will make a separate file comparing the datasets
+    gene_sig <- gene_sigs_list[[names_sigs[k]]] # load the gene signature
+    if(is.matrix(gene_sig)){gene_sig = as.vector(gene_sig);}
+    #set up canvas for plotting
+
+    if (showResults){
+      grDevices::dev.new()
+    }else{
+      grDevices::pdf(file.path(out_dir,paste0('sig_compare_ES_metrics_',names_sigs[k],'.pdf')),width=3*length(names_datasets),height=7.5)
+    }
+
+    #find the max number of characters in the title
+    max_title_length <- -999
+    for( i in 1:length(names_datasets)){
+      if(max_title_length < nchar(paste0(names_datasets[i],' ',names_sigs[k]))){
+        max_title_length <- nchar(paste0(names_datasets[i],' ',names_sigs[k]))
+      }
+    }
+    #set up the canvas
+    graphics::par(mfcol = c(3,length(names_datasets)),mar=c(4,4,4,4))
+
+    for ( i in 1:length(names_datasets)){
+      # now we can loop over the datasets for the plot and generate the metrics for every dataset with this signature
+      data.matrix = mRNA_expr_matrix[[names_datasets[i]]] #load the data
+      data.matrix[!(is.finite(as.matrix(data.matrix)))] <- NA #ensure that the data is not infintie
+      inter = intersect(gene_sig,rownames(data.matrix)) #consider only the genes actually present in the data
+      
+      med_scores <- apply(data.matrix[inter,],2,function(x){stats::median(stats::na.omit(x))}) #compute median
+      mean_scores <- apply(data.matrix[inter,],2,function(x){mean(stats::na.omit(x))}) #compute mean
+      pca1_scores <- NULL
+      tryCatch({
+        pca1_scores <- stats::prcomp(stats::na.omit(t(data.matrix[inter,])),retx=T) #compute PCA1
+        output_mat <- pca1_scores$x
+        if(!is.null(colnames(data.matrix))){
+          row.names(output_mat) <- colnames(data.matrix)
+        }
+        utils::write.table(output_mat,file=file.path(out_dir,'metrics_tables', paste0('pca_loadings_',names_sigs[k],'_',names_datasets[i],'.txt')),quote=F,sep='\t')
+
+        },error=function(e){
+          pca1_scores <<- NULL
+     #     print(paste0("error: ", e))
+      })
+
+      #need the matrix to be a  matrix not a dataframe
+      data.matrix.gsva <- data.matrix
+      if(!is.matrix(data.matrix)){
+        data.matrix.gsva <- as.matrix.data.frame(data.matrix,rownames.force=T)
+      }
+      es.ssGSEA <- suppressWarnings(GSVA::gsva(data.matrix.gsva, list(inter), method="ssgsea", verbose=F, parallel.sz=1))
+      es.gsva <- suppressWarnings(GSVA::gsva(data.matrix.gsva, list(inter),  verbose=F, parallel.sz=1))
+      es.plage <- suppressWarnings(GSVA::gsva(data.matrix.gsva, list(inter), method="plage", verbose=F, parallel.sz=1))
+    
+      es.gsva <- es.gsva[1,]
+      es.ssGSEA <- es.ssGSEA[1,]
+      es.plage <- es.plage[1,]
+      
+      common_score_cols <- intersect(names(es.gsva),intersect(names(es.ssGSEA),names(es.plage))) #ensures we have the same samples for each plot
+
+      if(length(common_score_cols) > 1){
+        #the following is the colourmap for the 2D scatter
+        jet.colors <- grDevices::colorRampPalette(c("#00007F", "blue", "#007FFF", "cyan", "#7FFF7F", "yellow", "#FF7F00", "red", "#7F0000"))
+        #plotting commands for the 2D scatterplot for mean-median correlation as follows
+        graphics::smoothScatter(es.gsva[common_score_cols],es.ssGSEA[common_score_cols],colramp = jet.colors,xlab=NA,ylab=NA,main='GSVA vs ssGSEA')
+        graphics::points(es.gsva[common_score_cols],es.ssGSEA[common_score_cols],pch='.') #draw the points on top of it
+        graphics::par(new=T)#,srt=45)
+        graphics::plot(stats::density(es.gsva[common_score_cols]), axes=F, xlab=NA, ylab=NA,  col='red',main=NA,lwd=2) #draw the density plot behind it
+        graphics::axis(side = 4)
+        graphics::mtext(side = 4, line = 2, 'Density',cex=0.8) #labels for the axes
+        graphics::mtext(side = 2, line = 2, 'ssGSEA',cex=0.8)
+        graphics::mtext(side = 1, line = 2, 'GSVA',cex=0.8)
+        graphics::mtext(side=3,line=2.5,paste0(names_datasets[i],' ',names_sigs[k]),cex=min(1,3*10/max_title_length)) #title
+        rho <- stats::cor(es.gsva[common_score_cols],es.ssGSEA[common_score_cols],method='spearman') 
+        rho_ssGSEA_gvsa <- rho
+        graphics::mtext(paste0('rho = ',format(rho,digits = 2)),side=3,line=0,cex = 0.6,at=max(es.gsva[common_score_cols]))
+      }else{
+        graphics::plot.new()
+        graphics::mtext(side=3,line=2.5,paste0(names_datasets[i],' ',names_sigs[k]),cex=min(1,3*10/max_title_length)) #title
+
+        graphics::title(paste0('\n\nToo many NA values for ssGSEA/GSVA in \n',names_datasets[i],' ',names_sigs[k]))#cex=min(1,4*10/max_title_length))
+        rho_ssGSEA_gvsa <- 0
+      }
+
+      if(length(common_score_cols) > 1){
+        #plotting for the ssGSEA-PLAGE
+        graphics::smoothScatter(es.ssGSEA[common_score_cols],es.plage[common_score_cols],colramp = jet.colors,xlab=NA,ylab=NA,main='ssGSEA vs PLAGE')
+        graphics::points(es.ssGSEA[common_score_cols],es.plage[common_score_cols],pch='.')
+        graphics::par(new=T)
+        graphics::plot(stats::density(es.ssGSEA[common_score_cols]), axes=F, xlab=NA, ylab=NA, col='red',main=NA,lwd=2)
+        graphics::axis(side = 4)
+        graphics::mtext(side = 4, line = 2, 'Density',cex=0.8)
+        rho <- stats::cor(es.ssGSEA[common_score_cols],es.plage[common_score_cols],method='spearman')
+        rho_ssGSEA_plage <- rho
+        graphics::mtext(paste0('rho = ',format(rho,digits = 2)),side=3,line=0,cex = 0.6,at=max(es.ssGSEA[common_score_cols]))
+        graphics::mtext(side = 2, line = 2, 'PLAGE',cex=0.8)
+        graphics::mtext(side = 1, line = 2, 'ssGSEA',cex=0.8)
+      }else{
+
+#        graphics::par(new=T)
+        graphics::plot.new()
+        graphics::title(paste0('\n\nToo many NA values for PLAGE/ssGSEA in \n',names_datasets[i],' ',names_sigs[k]))#cex=min(1,4*10/max_title_length))
+        rho_ssGSEA_plage <- 0
+      }
+      if(length(common_score_cols) > 1){
+        graphics::smoothScatter(es.plage[common_score_cols],es.gsva[common_score_cols],colramp = jet.colors,xlab=NA,ylab=NA,main='PLAGE vs GSVA')
+        graphics::points(es.plage[common_score_cols],es.gsva[common_score_cols],pch='.')
+        graphics::par(new=T)
+        graphics::plot(stats::density(es.plage[common_score_cols]), axes=F, xlab=NA, ylab=NA, col='red',main=NA,lwd=2)
+        graphics::axis(side = 4)
+        graphics::mtext(side = 4, line = 2, 'Density',cex=0.8)
+        rho <- stats::cor(es.plage[common_score_cols],es.gsva[common_score_cols],method='spearman')
+        rho_plage_gsva <- rho
+        graphics::mtext(paste0('rho = ',format(rho,digits = 2)),side=3,line=0,cex = 0.6,at=max(es.plage[common_score_cols]))
+        graphics::mtext(side = 2, line = 2, 'GSVA',cex=0.8)
+        graphics::mtext(side = 1, line = 2, 'PLAGE',cex=0.8)
+        }else{
+
+ #       graphics::par(new=T)
+        graphics::plot.new()
+        graphics::title(paste0('\n\nToo many NA values for GSVA/PLAGE in \n',names_datasets[i],' ',names_sigs[k]))#cex=min(1,4*10/max_title_length))
+        rho_plage_gsva <- 0
+
+      }
+       # print(paste0("test ",pca1_scores ))
+      if(length(pca1_scores) > 1){#!is.null(pca1_scores)){
+        props_of_variances <- pca1_scores$sdev^2/(sum(pca1_scores$sdev^2)) #for the scree plot
+        pca1_scores <- pca1_scores$x[,1] #takes the actual PCA1 scores
+        common_score_cols <- intersect(common_score_cols,intersect(names(med_scores),intersect(names(mean_scores),names(pca1_scores)))) #ensures we have the same samples for each plot
+      }else{
+        common_score_cols <- intersect(common_score_cols,intersect(names(med_scores),names(mean_scores)))
+      }
+
+      #here we output the table of mean, median and pca1 scores for each sample to a table
+
+      if((length(common_score_cols) > 1) & (!is.null(pca1_scores)) ){
+        common_score_cols <- intersect(common_score_cols,names(pca1_scores))
+        output_mat <- cbind(mean_scores[common_score_cols],med_scores[common_score_cols],pca1_scores[common_score_cols],es.ssGSEA[common_score_cols],cbind(es.gsva[common_score_cols],es.plage[common_score_cols]))
+        colnames(output_mat) <- c('Mean_Scores','Median_Scores','PCA1_Scores','ssGSEA','GSVA','PLAGE')
+        utils::write.table(output_mat,file=file.path(out_dir,'metrics_tables', paste0('metrics_table_',names_sigs[k],'_',names_datasets[i],'.txt')),quote=F,sep='\t')
+
+      }else if( length(common_score_cols) > 1){
+        output_mat <- cbind(mean_scores[common_score_cols],med_scores[common_score_cols],es.ssGSEA[common_score_cols],cbind(es.gsva[common_score_cols],es.plage[common_score_cols]))
+        colnames(output_mat) <- c('Mean_Scores','Median_Scores','ssGSEA','GSVA','PLAGE')
+        utils::write.table(output_mat,file=file.path(out_dir,'metrics_tables', paste0('metrics_table_',names_sigs[k],'_',names_datasets[i],'.txt')),quote=F,sep='\t')
+
+      }
+      score_cor_mats[[paste0(names_datasets[i],'_',names_sigs[k])]]<- stats::cor(output_mat,method='spearman')
+
+    }
+    #saves file
+    if(showResults){
+      grDevices::dev.copy(grDevices::pdf,file.path(out_dir,paste0('sig_compare_ES_metrics_',names_sigs[k],'.pdf')),width=3*length(names_datasets),height=7.5)
+    }
+    if(grDevices::dev.cur()!=1){
+        g <- grDevices::dev.off() # to reset the graphics pars to defaults
+    }
+    
+  }
+ cat('ES scores computed successfully.\n', file=file) #output to log
+
+#-----now we need to output the score correlation matrices as heatmaps----
+  for(k in 1:length(names_sigs)){ 
+    for ( i in 1:length(names_datasets)){
+#now we compute and output the correlation of scoring metrics in heatmap form
+      plot_mat <- score_cor_mats[[paste0(names_datasets[i],'_',names_sigs[k])]]
+      if (showResults){
+        grDevices::dev.new()
+      }else{
+        grDevices::pdf(file.path(out_dir,paste0('scoring_metrics_corr_',names_datasets[i],'_',names_sigs[k],'.pdf')),width=4,height=4)
+      }
+      #set up the canvas
+      graphics::par(mfcol = c(4,length(names_datasets)),mar=c(4,4,4,4))
+      nice_row_names <- c('Mean','Median','PCA1','GVSA','ssGSEA','PLAGE')
+      names(nice_row_names) <- c('Mean_Scores','Median_Scores','PCA1_Scores','GSVA','ssGSEA','PLAGE')
+      row_names.fontsize <- 10
+      row.names(plot_mat) <- nice_row_names[rownames(plot_mat)]
+      ans_hmap <- ComplexHeatmap::Heatmap(plot_mat,show_column_dend = F,
+                                              show_column_names = F,
+                                              name=names_datasets[i],
+                                              col= circlize::colorRamp2(c(-1, 0, 1), c("blue", "white", "red")),
+                                              heatmap_legend_param = list(title = 'Correlation', color_bar = "continuous",legend_direction='vertical'),
+                                              column_title = paste0(names_datasets[i],' ',names_sigs[k],'\nScoring Metric Correlation'),
+                                              row_names_gp =  grid::gpar(fontsize = row_names.fontsize),
+                                              row_title = 'Scoring metrics')#,
+      
+      ComplexHeatmap::draw(ans_hmap,heatmap_legend_side = "left")
+
+      #saves file
+      if(showResults){
+        grDevices::dev.copy(grDevices::pdf,file.path(out_dir,paste0('scoring_metrics_corr_',names_datasets[i],'_',names_sigs[k],'.pdf')),width=7,height=3.5)
+      }
+      if(grDevices::dev.cur()!=1){
+          g <- grDevices::dev.off() # to reset the graphics pars to defaults
+      }
+  }
+}
+ #-----------------------------------------------------------------------------------------------------------
+
   #------------------------------------------------------------------------------------------------------------------
 
   #next we use the mclust package, and compute the log-likelihoods of the various Gaussian mixture models for the scores
